@@ -192,7 +192,6 @@ def sync(config, state, stream):
     finished_shard_bookmarks = singer.get_bookmark(state, table_name, 'finished_shards')
     if not finished_shard_bookmarks:
         finished_shard_bookmarks = []
-    LOGGER.info("Finished Shard Bookmarks Here :",finished_shard_bookmarks)
     # The list of shardIds we found this sync. Is used to determine which
     # finished_shard_bookmarks to kill
     found_shards = []
@@ -203,13 +202,10 @@ def sync(config, state, stream):
 
     for shard in get_shards(streams_client, stream_arn):
         found_shards.append(shard['ShardId'])
-        # Only sync shards which we have not fully synced already
-        if shard['ShardId'] not in finished_shard_bookmarks:
-            rows_synced += sync_shard(shard, seq_number_bookmarks,
-                                      streams_client, stream_arn, projection, deserializer,
-                                      table_name, stream_version, state)
-        else :
-            LOGGER.info("Found in FInished shards id",shard['ShardId'])
+        # Only sync shards which we have not fully synced alreadymake      
+        rows_synced += sync_shard(shard, seq_number_bookmarks,
+                                    streams_client, stream_arn, projection, deserializer,
+                                    table_name, stream_version, state)
         # Now that we have fully synced the shard, move it from the
         # shard_seq_numbers to finished_shards.
         finished_shard_bookmarks.append(shard['ShardId'])
